==> iReport-1.2.3-src.zip: iReport-1.2.3-src/src/it/businesslogic/ireport/chart/HighLowDataset.java <==
/*
 * PieDataset.java
 *
 * Created on 15 agosto 2005, 17.49
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;
import java.util.*;
/**
 *
 * @author Administrator
 */
public class HighLowDataset extends Dataset {
    
    private String seriesExpression = "";
    private String dateExpression = "";
    private String highExpression = "";
    private String lowExpression = "";
    private String openExpression = "";
    private String closeExpression = "";
    private String volumeExpression = "";
    
    /** Creates a new instance of PieDataset */
    public HighLowDataset() {
        super();
    }   

    public String getSeriesExpression() {
        return seriesExpression;
    }

    public void setSeriesExpression(String seriesExpression) {
        this.seriesExpression = seriesExpression;
    }

    public String getDateExpression() {
        return dateExpression;
    }

    public void setDateExpression(String dateExpression) {
        this.dateExpression = dateExpression;
    }

    public String getHighExpression() {
        return highExpression;
    }

    public void setHighExpression(String highExpression) {
        this.highExpression = highExpression;
    }

    public String getLowExpression() {
        return lowExpression;
    }

    public void setLowExpression(String lowExpression) {
        this.lowExpression = lowExpression;
    }

    public String getOpenExpression() {
        return openExpression;
    }

    public void setOpenExpression(String openExpression) {
        this.openExpression = openExpression;
    }

    public String getCloseExpression() {
        return closeExpression;
    }

    public void setCloseExpression(String closeExpression) {
        this.closeExpression = closeExpression;
    }

    public String getVolumeExpression() {
        return volumeExpression;
    }

    public void setVolumeExpression(String volumeExpression) {
        this.volumeExpression = volumeExpression;
    }
    
    public Dataset cloneMe()
    {
        HighLowDataset obj = new HighLowDataset();
        copyBaseDataset(obj);
        obj.setSeriesExpression(getSeriesExpression());
        obj.setDateExpression( getDateExpression());
        obj.setCloseExpression( getCloseExpression());
        obj.setOpenExpression( getOpenExpression());
        obj.setHighExpression( getHighExpression());
        obj.setLowExpression( getLowExpression() );
        obj.setVolumeExpression( getVolumeExpression());
        
        return obj;
    }
}

==> iReport-1.2.7-src.zip: iReport-1.2.7-src/src/it/businesslogic/ireport/chart/HighLowDataset.java <==
/*
 * PieDataset.java
 *
 * Created on 15 agosto 2005, 17.49
 *
 * To change this template, choose Tools | Options and locate the template under
 * the Source Creation and Management node. Right-click the template and choose
 * Open. You can then make changes to the template in the Source Editor.
 */

package it.businesslogic.ireport.chart;
import java.util.*;
/**
 *
 * @author Administrator
 */
public class HighLowDataset extends Dataset {
    
    private String seriesExpression = "";
    private String dateExpression = "";
    private String highExpression = "";
    private String lowExpression = "";
    private String openExpression = "";
    private String closeExpression = "";
    private String volumeExpression = "";
    private SectionItemHyperlink sectionHyperLink = new SectionItemHyperlink();
    
    /** Creates a new instance of PieDataset */
    public HighLowDataset() {
        super();
    }   

    public String getSeriesExpression() {
        return seriesExpression;
    }

    public void setSeriesExpression(String seriesExpression) {
        this.seriesExpression = seriesExpression;
    }

    public String getDateExpression() {
        return dateExpression;
    }

    public void setDateExpression(String dateExpression) {
        this.dateExpression = dateExpression;
    }

    public String getHighExpression() {
        return highExpression;
    }

    public void setHighExpression(String highExpression) {
        this.highExpression = highExpression;
    }

    public String getLowExpression() {
        return lowExpression;
    }

    public void setLowExpression(String lowExpression) {
        this.lowExpression = lowExpression;
    }

    public String getOpenExpression() {
        return openExpression;
    }

    public void setOpenExpression(String openExpression) {
        this.openExpression = openExpression;
    }

    public String getCloseExpression() {
        return closeExpression;
    }

    public void setCloseExpression(String closeExpression) {
        this.closeExpression = closeExpression;
    }

    public String getVolumeExpression() {
        return volumeExpression;
    }

    public void setVolumeExpression(String volumeExpression) {
        this.volumeExpression = volumeExpression;
    }
    
    public Dataset cloneMe()
    {
        HighLowDataset obj = new HighLowDataset();
        copyBaseDataset(obj);
        obj.setSeriesExpression(getSeriesExpression());
        obj.setDateExpression( getDateExpression());
        obj.setCloseExpression( getCloseExpression());
        obj.setOpenExpression( getOpenExpression());
        obj.setHighExpression( getHighExpression());
        obj.setLowExpression( getLowExpression() );
        obj.setVolumeExpression( getVolumeExpression());
        obj.setItemHyperLink( getItemHyperLink().cloneMe());
        
        return obj;
    }

    public SectionItemHyperlink getItemHyperLink() {
        return sectionHyperLink;
    }

    public void setItemHyperLink(SectionItemHyperlink secionHyperLink) {
        this.sectionHyperLink = secionHyperLink;
    }
}
